Class: Restate::Request

Inherits:
Struct
  • Object
show all
Defined in:
lib/restate/context.rb

Overview

Request metadata available to handlers via ctx.request.

Instance Attribute Summary collapse

Instance Attribute Details

#attempt_finished_eventAttemptFinishedEvent (readonly)

Returns signaled when this attempt ends.

Returns:



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#bodyString (readonly)

Returns raw input bytes.

Returns:

  • (String)

    raw input bytes



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#headersHash{String => String} (readonly)

Returns request headers.

Returns:

  • (Hash{String => String})

    request headers



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#idString (readonly)

Returns the invocation ID.

Returns:

  • (String)

    the invocation ID



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#idempotency_keyString? (readonly)

Returns the idempotency key this invocation was made with, if any.

Returns:

  • (String, nil)

    the idempotency key this invocation was made with, if any



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#limit_keyString? (readonly)

Returns the concurrency limit key this invocation was made with, if any.

Returns:

  • (String, nil)

    the concurrency limit key this invocation was made with, if any



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)

#scopeString? (readonly)

Returns the scope this invocation was routed within, if any.

Returns:

  • (String, nil)

    the scope this invocation was routed within, if any



72
73
# File 'lib/restate/context.rb', line 72

Request = Struct.new(:id, :headers, :body, :attempt_finished_event,
:scope, :limit_key, :idempotency_key, keyword_init: true)