Class: Restate::Request
- Inherits:
-
Struct
- Object
- Struct
- Restate::Request
- Defined in:
- lib/restate/context.rb
Overview
Request metadata available to handlers via ctx.request.
Instance Attribute Summary collapse
-
#attempt_finished_event ⇒ AttemptFinishedEvent
readonly
Signaled when this attempt ends.
-
#body ⇒ String
readonly
Raw input bytes.
-
#headers ⇒ Hash{String => String}
readonly
Request headers.
-
#id ⇒ String
readonly
The invocation ID.
-
#idempotency_key ⇒ String?
readonly
The idempotency key this invocation was made with, if any.
-
#limit_key ⇒ String?
readonly
The concurrency limit key this invocation was made with, if any.
-
#scope ⇒ String?
readonly
The scope this invocation was routed within, if any.
Instance Attribute Details
#attempt_finished_event ⇒ AttemptFinishedEvent (readonly)
Returns signaled when this attempt ends.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#body ⇒ String (readonly)
Returns raw input bytes.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#headers ⇒ Hash{String => String} (readonly)
Returns request headers.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#id ⇒ String (readonly)
Returns the invocation ID.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#idempotency_key ⇒ String? (readonly)
Returns the idempotency key this invocation was made with, if any.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#limit_key ⇒ String? (readonly)
Returns the concurrency limit key this invocation was made with, if any.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |
#scope ⇒ String? (readonly)
Returns the scope this invocation was routed within, if any.
72 73 |
# File 'lib/restate/context.rb', line 72 Request = Struct.new(:id, :headers, :body, :attempt_finished_event, :scope, :limit_key, :idempotency_key, keyword_init: true) |