Exception: Restate::SuspendedError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/restate/errors.rb

Overview

Internal: raised when the VM suspends execution. User code should NOT catch this.

Instance Method Summary collapse

Constructor Details

#initializeSuspendedError

Returns a new instance of SuspendedError.



21
22
23
24
25
26
27
28
# File 'lib/restate/errors.rb', line 21

def initialize
  super(
    "Invocation got suspended, Restate will resume this invocation when progress can be made.\n" \
    "This exception is safe to ignore. If you see it, you might be using a bare rescue.\n\n" \
    "Don't do:\nbegin\n  # Code\nrescue => e\n  # This catches SuspendedError!\nend\n\n" \
    "Do instead:\nbegin\n  # Code\nrescue Restate::TerminalError => e\n  # Handle terminal errors\nend"
  )
end